@@ -193,7 +193,7 @@ class SelfcheckPatronInformation(dict):
         self['charged_items'] = []
         self['fine_items'] = []
         self['recall_items'] = []
-        self['unavailable_items'] = []
+        self['unavailable_hold_items'] = []
         self['screen_messages'] = []
 
         # optional properties
@@ -462,6 +462,32 @@ class SelfcheckRenew(dict):
         return self.get('magnetic_media')
 
 
+class SelfcheckFeePaid(dict):
+    """Class representing fee paid handler response."""
+
+    def __init__(self, accepted=False, **kwargs):
+        """Constructor.
+
+        :param accepted: payment operation is accepted or not
+            should be set to True if the ACS accept the payment.
+            should be set to 0 if the ACS did not accept the payment.
+        :param kwargs: optional fields
+        """
+        # required properties
+        self['payment_accepted'] = accepted
+        self['screen_messages'] = []
+
+        # optional properties
+        for key, value in kwargs.items():
+            if value:
+                self[key] = value
+
+    @property
+    def is_accepted(self):
+        """Shortcut for payment_accepted operation."""
+        return self.get('payment_accepted', False)
+
+
 class SelfcheckLanguage(Enum):
     """Enum class to list all available language."""
 
@@ -547,6 +573,14 @@ class SelfcheckFeeType(object):
     HOLD_FEE = '09'
 
 
+class SelfcheckPaymentType(object):
+    """Class to handle all available payment type."""
+
+    CASH = '00'
+    VISA = '01'
+    CREDIT_CARD = '02'
+
+
 class SelfcheckMediaType(object):
     """Class to handle all available media type."""
 
@@ -590,19 +624,19 @@ class SelfcheckSummary:
         'charged_items',
         'fine_items',
         'recall_items',
-        'unavailable_items',
+        'unavailable_hold_items',
     ]
 
     def __init__(self, text):
         """Init."""
         from .utils import decode_char_to_bool
-        self.hold_items = decode_char_to_bool(text[0:])
+        self.hold_items = decode_char_to_bool(text[0])
         self.overdue_items = decode_char_to_bool(text[1])
         self.charged_items = decode_char_to_bool(text[2])
         self.fine_items = decode_char_to_bool(text[3])
         self.recall_items = decode_char_to_bool(text[4])
-        self.unavailable_items = decode_char_to_bool(text[5])
+        self.unavailable_hold_items = decode_char_to_bool(text[5])
 
     def is_needed(self, key):
         """Check if the given information is needed."""
-        return hasattr(self, key)
+        return getattr(self, key, False)
